@@ -20,9 +20,9 @@
 
 /* MONGOC_USER_SET_CFLAGS is set from config based on what compiler flags were
  * used to compile mongoc */
-#define MONGOC_USER_SET_CFLAGS "-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4"
+#define MONGOC_USER_SET_CFLAGS "-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe -fstack-protector-strong -fno-plt"
 
-#define MONGOC_USER_SET_LDFLAGS "-Wl,-O1,--sort-common,--as-needed,-z,relro"
+#define MONGOC_USER_SET_LDFLAGS "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
 
 /* MONGOC_CC is used to determine what C compiler was used to compile mongoc */
 #define MONGOC_CC "gcc"
@@ -136,6 +136,16 @@
 #endif
 
 
+/*
+ * Use ASN1_STRING_get0_data () rather then the deprecated ASN1_STRING_data
+ */
+#define MONGOC_HAVE_ASN1_STRING_GET0_DATA 1
+
+#if MONGOC_HAVE_ASN1_STRING_GET0_DATA != 1
+#  undef MONGOC_HAVE_ASN1_STRING_GET0_DATA
+#endif
+
+
 /*
  * MONGOC_ENABLE_SASL is set from configure to determine if we are
  * compiled with SASL support.
@@ -169,6 +179,17 @@
 #endif
 
 
+/*
+ * MONGOC_ENABLE_SASL_GSSAPI is set from configure to determine if we are
+ * compiled with GSSAPI support.
+ */
+#define MONGOC_ENABLE_SASL_GSSAPI 0
+
+#if MONGOC_ENABLE_SASL_GSSAPI != 1
+#  undef MONGOC_ENABLE_SASL_GSSAPI
+#endif
+
+
 /*
  * MONGOC_HAVE_SASL_CLIENT_DONE is set from configure to determine if we
  * have SASL and its version is new enough to use sasl_client_done (),
@@ -222,6 +243,38 @@
 #define MONGOC_SOCKET_ARG2 struct sockaddr
 #define MONGOC_SOCKET_ARG3 socklen_t
 
+/*
+ * Enable wire protocol compression negotiation
+ *
+ */
+#define MONGOC_ENABLE_COMPRESSION 1
+
+#if MONGOC_ENABLE_COMPRESSION != 1
+#  undef MONGOC_ENABLE_COMPRESSION
+#endif
+
+/*
+ * Set if we have snappy compression support
+ *
+ */
+#define MONGOC_ENABLE_COMPRESSION_SNAPPY 0
+
+#if MONGOC_ENABLE_COMPRESSION_SNAPPY != 1
+#  undef MONGOC_ENABLE_COMPRESSION_SNAPPY
+#endif
+
+
+/*
+ * Set if we have zlib compression support
+ *
+ */
+#define MONGOC_ENABLE_COMPRESSION_ZLIB 1
+
+#if MONGOC_ENABLE_COMPRESSION_ZLIB != 1
+#  undef MONGOC_ENABLE_COMPRESSION_ZLIB
+#endif
+
+
 /*
  * NOTICE:
  * If you're about to update this file and add a config flag, make sure to
